/*
 * SM_HeuristicClassification.java
 *
 * Created on 30 January 2016
 *
 * Version 1.0
 *
 * Copyright (C) Kieran Greer
 */

package org.licas.ai.solver;


import org.ai_heuristic.model.FactoryInfo;
import java.util.*;
import org.ai_heuristic.util.AiHeuristicConst;
import org.licas.ai.solver.util.SM_HeuristicConst;
import org.licas.ai.solver.wrapper.SM_StringMetric;
import org.licas.ai_solver.HeuristicClassification;


/**
 * This class describes the methods to classify the different heuristic types. 
 * This class is typically used by the other heuristic factory implementors to
 * determine type or return general information.
 * @author Kieran Greer
 */
public class SM_HeuristicClassification extends HeuristicClassification
{
    /** 
     * List of modules automatically loaded in during startup. Of type {@link ModuleHeuristicFactory}.
     */
    protected static ArrayList heuristicModules = new ArrayList();
    
    /** 
     * Create a new instance of SM_HeuristicClassification. 
     * @param theHeuristicModules list of heuristic modules.
     */
    public SM_HeuristicClassification(ArrayList theHeuristicModules)
    {
        heuristicModules = theHeuristicModules;
    }
    
    
    /**
     * Get a factory info object for the specified heuristic or evaluator type.
     * @param heuristicType the AI type to check for.
     * @return a factory info object with related information.
     */
    public FactoryInfo getFactoryInfo(String heuristicType)
    {
        FactoryInfo factoryInfo;                        //info object
        
        factoryInfo = null;
        if (heuristicType != null)
        {
            if (heuristicType.equals(SM_HeuristicConst.SM_BLOCKDISTANCE))
            {
                factoryInfo = new FactoryInfo();
                factoryInfo.serviceType = AiHeuristicConst.METRIC;
                factoryInfo.className = SM_StringMetric.class.getName();
                factoryInfo.filePath = null;
                factoryInfo.description = "Simmetrics Block Distance function. SIB.";
            }
            else if (heuristicType.equals(SM_HeuristicConst.SM_COSINESIMILARITY))
            {
                factoryInfo = new FactoryInfo();
                factoryInfo.serviceType = AiHeuristicConst.METRIC;
                factoryInfo.className = SM_StringMetric.class.getName();
                factoryInfo.filePath = null;
                factoryInfo.description = "Simmetrics Cosine Similarity function. SIB.";
            }
            else if (heuristicType.equals(SM_HeuristicConst.SM_DEMERAULEVENSHTEIN))
            {
                factoryInfo = new FactoryInfo();
                factoryInfo.serviceType = AiHeuristicConst.METRIC;
                factoryInfo.className = SM_StringMetric.class.getName();
                factoryInfo.filePath = null;
                factoryInfo.description = "Simmetrics Demerau Levenshtein function. SIB.";
            }
            else if (heuristicType.equals(SM_HeuristicConst.SM_JARO))
            {
                factoryInfo = new FactoryInfo();
                factoryInfo.serviceType = AiHeuristicConst.METRIC;
                factoryInfo.className = SM_StringMetric.class.getName();
                factoryInfo.filePath = null;
                factoryInfo.description = "Simmetrics Jaro function. SIB.";
            }
            else if (heuristicType.equals(SM_HeuristicConst.SM_JAROWINKLER))
            {
                factoryInfo = new FactoryInfo();
                factoryInfo.serviceType = AiHeuristicConst.METRIC;
                factoryInfo.className = SM_StringMetric.class.getName();
                factoryInfo.filePath = null;
                factoryInfo.description = "Simmetrics Jaro Winkler function. SIB.";
            }
            else if (heuristicType.equals(SM_HeuristicConst.SM_LEVENSHTEIN))
            {
                factoryInfo = new FactoryInfo();
                factoryInfo.serviceType = AiHeuristicConst.METRIC;
                factoryInfo.className = SM_StringMetric.class.getName();
                factoryInfo.filePath = null;
                factoryInfo.description = "Simmetrics Levenshtein function. SIB.";
            }
            else if (heuristicType.equals(SM_HeuristicConst.SM_NEEDLEMANWUNCH))
            {
                factoryInfo = new FactoryInfo();
                factoryInfo.serviceType = AiHeuristicConst.METRIC;
                factoryInfo.className = SM_StringMetric.class.getName();
                factoryInfo.filePath = null;
                factoryInfo.description = "Simmetrics Needleman Wunch function. SIB.";
            }
            else if (heuristicType.equals(SM_HeuristicConst.SM_SMITHWATERMAN))
            {
                factoryInfo = new FactoryInfo();
                factoryInfo.serviceType = AiHeuristicConst.METRIC;
                factoryInfo.className = SM_StringMetric.class.getName();
                factoryInfo.filePath = null;
                factoryInfo.description = "Simmetrics Smith Waterman function. SIB.";
            }
            else if (heuristicType.equals(SM_HeuristicConst.SM_SMITHWATERMANGOTOH))
            {
                factoryInfo = new FactoryInfo();
                factoryInfo.serviceType = AiHeuristicConst.METRIC;
                factoryInfo.className = SM_StringMetric.class.getName();
                factoryInfo.filePath = null;
                factoryInfo.description = "Simmetrics Smith Waterman Gotoh function. SIB.";
            }
        }
        
        return factoryInfo;
    }
}
