/*
 * SM_HeuristicMetrics.java
 *
 * Created on 30 January 2016
 *
 * Version 1.0
 *
 * Copyright (C) Kieran Greer
 */

package org.licas.ai.solver;


import java.util.*;
import org.licas.ai.solver.util.SM_HeuristicConst;
import org.licas.ai_solver.HeuristicClassification;
import org.licas.ai_solver.HeuristicMetrics;


/**
 * This class describes the methods used by the heuristic metrics. A copy is stored in the
 * {@link HeuristicFactory} from where it is accessed and used.
 * @author Kieran Greer
 */
public class SM_HeuristicMetrics extends HeuristicMetrics
{
    /** 
     * Create a new instance of SM_HeuristicMetrics. 
     * @param theHeuristicClassif the heuristic classifications.
     * @param theHeuristicModules list of heuristic modules.
     */
    public SM_HeuristicMetrics(HeuristicClassification theHeuristicClassif, ArrayList theHeuristicModules)
    {
        super(theHeuristicClassif, theHeuristicModules);
    }
    
    
    /**
     * Get a list of available versions of a evaluation metric type.
     * @param heuristicType the heuristic type.
     * @return the list of versions of the metric evaluator the heuristic can use.
     */
    public HashMap getMetricVersions(String heuristicType)
    {
        HashMap typeList;                             //list of types
        
        typeList = new HashMap();
        if (heuristicType != null)
        {
            typeList.put(SM_HeuristicConst.SM_BLOCKDISTANCE,
                heuristicClassif.getFactoryInfo(SM_HeuristicConst.SM_BLOCKDISTANCE));
            typeList.put(SM_HeuristicConst.SM_COSINESIMILARITY,
                heuristicClassif.getFactoryInfo(SM_HeuristicConst.SM_COSINESIMILARITY));
            typeList.put(SM_HeuristicConst.SM_DEMERAULEVENSHTEIN,
                heuristicClassif.getFactoryInfo(SM_HeuristicConst.SM_DEMERAULEVENSHTEIN));
            typeList.put(SM_HeuristicConst.SM_JARO,
                heuristicClassif.getFactoryInfo(SM_HeuristicConst.SM_JARO));
            typeList.put(SM_HeuristicConst.SM_JAROWINKLER,
                heuristicClassif.getFactoryInfo(SM_HeuristicConst.SM_JAROWINKLER));
            typeList.put(SM_HeuristicConst.SM_LEVENSHTEIN,
                heuristicClassif.getFactoryInfo(SM_HeuristicConst.SM_LEVENSHTEIN));
            typeList.put(SM_HeuristicConst.SM_NEEDLEMANWUNCH,
                heuristicClassif.getFactoryInfo(SM_HeuristicConst.SM_NEEDLEMANWUNCH));
            typeList.put(SM_HeuristicConst.SM_SMITHWATERMAN,
                heuristicClassif.getFactoryInfo(SM_HeuristicConst.SM_SMITHWATERMAN));
            typeList.put(SM_HeuristicConst.SM_SMITHWATERMANGOTOH,
                heuristicClassif.getFactoryInfo(SM_HeuristicConst.SM_SMITHWATERMANGOTOH));
        }
        
        return typeList;
    }
}
