/*
 * SM_SolverMetrics.java
 *
 * Created on 30 January 2016
 *
 * Version 1.0
 *
 * Copyright (C) Kieran Greer
 */

package org.licas.ai.solver;


import org.ai_heuristic.functs.*;
import org.ai_heuristic.def.EvaluateMathDef;

import java.util.*;
import org.licas.ai.solver.wrapper.SM_StringMetric;
import org.licas.ai_solver.SolverMetrics;


/**
 * This class describes the methods used by the solver metrics. A copy is stored in the
 * {@link DefaultSolverFactory} from where it is accessed and used.
 * @author Kieran Greer
 */
public class SM_SolverMetrics extends SolverMetrics
{
    /**
     * Create a new instance of SM_SolverMetrics.
     * @param theSolverModules list of solver modules.
     */
    public SM_SolverMetrics(ArrayList theSolverModules)
    {
        super(theSolverModules);
    }
    
    
    /**
     * Create and return the correct function/metric for the input parameters.
     * @param valueType the type of object being evaluated.
     * @param functionType the type of function to create.
     * @return the created evaluation function.
     * @throws java.lang.Exception any error.
     */
    public Function getEvaluationFunction(String valueType, String functionType) 
            throws Exception
    {
        return new SM_StringMetric(functionType);
    }
    
    /**
     * Create and return the correct function/metric for the input parameters. This calls
     * {@link Function}.{@code createFunction} in the first instance and tries to configure it.
     * @param valueType the type of object being evaluated.
     * @param functionType the type of function to create.
     * @param evaluateService the evaluator. Can be null for a default evaluator.
     * @param configParams a list of any input configuration parameters. Can be null for no parameters.
     * @return the created evaluation function.
     * @throws java.lang.Exception any error.
     */
    public Function getEvaluationFunction(String valueType, String functionType,
            EvaluateMathDef evaluateService, HashMap configParams) throws Exception
    {
        return new SM_StringMetric(functionType);
    }
}
